==> eole-workstation-joineole_2.7.2-14.tar.gz: eole-workstation-joineole-14/README.md <==
## eole-workstation-joineole

Démarrer un etb1 scribe avec PC Win7 
Vérifier le fonctionnement du pc Win7
- reboot
- controler c:\windows\temp\installMinion.log
- dans la session 'admin', vérifier %TEMP%\eole_script.log

### Procédure de compilation de `installMinion.exe`

- Soit avec Jenkins :
1. Modifier la branche de code
2. Pousser la branche de code sur la forge EOLE
3. Démarrer manuellement https://dev-eole.ac-dijon.fr/jenkins/job/Internes/job/eole-workstation-joineole/
4. Récuppérer le fichier https://dev-eole.ac-dijon.fr/jenkins/job/Internes/job/eole-workstation-joineole/ws/workstation/installMinion.exe
5. Faire un nouveau commit avec le fichier `exe` dans la branche de code
6. Construire un paquet avec la procédure `git package`

- Soit à la main :
1. Aller sur le PC Win71
2. lancer powershell 
3. cd c:\eole
4. .\connect_z.cmd
5. cd \\dompedago.etb1.lan\sysvol\dompedago.etb1.lan\Policies
6. Identifier la GPO Id
7. cd {GPO_ID}\Machine\Scripts\Startup
8. Copy-Item installMinion.ps1 z:\scripts\windows\installMinion\installMinion.ps1
9. z:
10. cd z:\scripts\windows\installMinion
11. & .\build-installMinion2.ps1
12. gci
13. Vérifier installMinion.exe, installMinion-GUI.exe 

# retour sur PC perso

- VM_OWNER=ggrandgerard

- cd eole-workstation-joineole
- git pull
- git status
- git checkout 2.7.2/master
- cd workstation/
- cp /mnt/eole-ci-tests/scripts/windows/installMinion/installMinion.ps1 installMinion.ps1
- cp /mnt/eole-ci-tests/scripts/windows/installMinion/installMinion.exe installMinion.exe
- cp /mnt/eole-ci-tests/scripts/windows/installMinion/installMinion-GUI.exe installMinion-GUI.exe
- cd ..
- ls -l workstation/installMinion*
- git status
- git add workstation/installMinion*
- git commit -m "blabla... REF #"
- git log
- git push
- git package 2.7.2/master
- git package -b -d eole-2.7.2/proposed-updates 2.7.2/master
- git checkout 2.8.0/master
- git pull
- git merge 2.7.2/master
- git status
- git push
- git package 2.8.0/master
- git package -b -d eole-2.8.0/proposed-updates 2.8.0/master
- git checkout 2.8.1/master
- git pull
- git merge 2.8.0/master
- git status
- git push
- git package 2.8.1/master
- git package -b -d eole-2.8.1/proposed-updates 2.8.1/master
- git checkout master
- git pull
- git merge 2.8.1/master
- git status
- git package 2.9.0/master
- git package -b -d eole-2.9/unstable 2.9.0/master
- git pull
- git push

# fini ouf!!!

==> eole-workstation-joineole_2.10.0-14.tar.gz: eole-workstation-joineole-14/README.md <==
## eole-workstation-joineole

Démarrer un etb1 scribe avec PC Win7 
Vérifier le fonctionnement du pc Win7
- reboot
- controler c:\windows\temp\installMinion.log
- dans la session 'admin', vérifier %TEMP%\eole_script.log

### Procédure de compilation de `installMinion.exe`

- Soit avec Jenkins :
1. Modifier la branche de code
2. Pousser la branche de code sur la forge EOLE
3. Démarrer manuellement https://dev-eole.ac-dijon.fr/jenkins/job/Internes/job/eole-workstation-joineole/
4. Récuppérer le fichier https://dev-eole.ac-dijon.fr/jenkins/job/Internes/job/eole-workstation-joineole/ws/workstation/installMinion.exe
5. Faire un nouveau commit avec le fichier `exe` dans la branche de code
6. Construire un paquet avec la procédure `git package`

- Soit à la main :
1. Aller sur le PC Win71
2. lancer powershell 
3. cd c:\eole
4. .\connect_z.cmd
5. cd \\dompedago.etb1.lan\sysvol\dompedago.etb1.lan\Policies
6. Identifier la GPO Id
7. cd {GPO_ID}\Machine\Scripts\Startup
8. Copy-Item installMinion.ps1 z:\scripts\windows\installMinion\installMinion.ps1
9. z:
10. cd z:\scripts\windows\installMinion
11. & .\build-installMinion2.ps1
12. gci
13. Vérifier installMinion.exe, installMinion-GUI.exe 

# retour sur PC perso

- VM_OWNER=ggrandgerard

- cd eole-workstation-joineole
- git pull
- git status
- git checkout 2.7.2/master
- cd workstation/
- cp /mnt/eole-ci-tests/scripts/windows/installMinion/installMinion.ps1 installMinion.ps1
- cp /mnt/eole-ci-tests/scripts/windows/installMinion/installMinion.exe installMinion.exe
- cp /mnt/eole-ci-tests/scripts/windows/installMinion/installMinion-GUI.exe installMinion-GUI.exe
- cd ..
- ls -l workstation/installMinion*
- git status
- git add workstation/installMinion*
- git commit -m "blabla... REF #"
- git log
- git push
- git package 2.7.2/master
- git package -b -d eole-2.7.2/proposed-updates 2.7.2/master
- git checkout 2.8.0/master
- git pull
- git merge 2.7.2/master
- git status
- git push
- git package 2.8.0/master
- git package -b -d eole-2.8.0/proposed-updates 2.8.0/master
- git checkout 2.8.1/master
- git pull
- git merge 2.8.0/master
- git status
- git push
- git package 2.8.1/master
- git package -b -d eole-2.8.1/proposed-updates 2.8.1/master
- git checkout master
- git pull
- git merge 2.8.1/master
- git status
- git package 2.9.0/master
- git package -b -d eole-2.9.0/proposed-updates 2.9.0/master
- git checkout master
- git pull
- git merge 2.9.0/master
- git status
- git package 2.10.0/master
- git package -b -d eole-2.10.0/proposed-updates 2.10.0/master
- #git package -b -d eole-2.9/unstable 2.9.0/master
- git pull
- git push

# fini ouf!!!
